summaryrefslogtreecommitdiffstats
path: root/kjsembed/tools/headers/qbrush.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /kjsembed/tools/headers/qbrush.h
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'kjsembed/tools/headers/qbrush.h')
-rw-r--r--kjsembed/tools/headers/qbrush.h58
1 files changed, 29 insertions, 29 deletions
diff --git a/kjsembed/tools/headers/qbrush.h b/kjsembed/tools/headers/qbrush.h
index 82b00044..93f17e28 100644
--- a/kjsembed/tools/headers/qbrush.h
+++ b/kjsembed/tools/headers/qbrush.h
@@ -1,7 +1,7 @@
/****************************************************************************
**
**
** Definition of TQBrush class
**
** Created : 940112
**
@@ -11,7 +11,7 @@
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
+** LICENSE.TQPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
@@ -27,7 +27,7 @@
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
** information about Qt Commercial License Agreements.
-** See http://www.trolltech.com/qpl/ for QPL licensing information.
+** See http://www.trolltech.com/qpl/ for TQPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
@@ -35,8 +35,8 @@
**
**********************************************************************/
-#ifndef QBRUSH_H
-#define QBRUSH_H
+#ifndef TQBRUSH_H
+#define TQBRUSH_H
#ifndef QT_H
#include "tqcolor.h"
@@ -44,48 +44,48 @@
#endif // QT_H
-class Q_EXPORT TQBrush: public Qt
+class Q_EXPORT TTQBrush: public Qt
{
-friend class TQPainter;
+friend class TTQPainter;
public:
- TQBrush();
- TQBrush( BrushStyle );
- TQBrush( const TQColor &, BrushStyle=SolidPattern );
- TQBrush( const TQColor &, const TQPixmap & );
- TQBrush( const TQBrush & );
- ~TQBrush();
- TQBrush &operator=( const TQBrush & );
+ TTQBrush();
+ TTQBrush( BrushStyle );
+ TTQBrush( const TTQColor &, BrushStyle=SolidPattern );
+ TTQBrush( const TTQColor &, const TTQPixmap & );
+ TTQBrush( const TTQBrush & );
+ ~TTQBrush();
+ TTQBrush &operator=( const TTQBrush & );
BrushStyle style() const { return data->style; }
void setStyle( BrushStyle );
- const TQColor &color()const { return data->color; }
- void setColor( const TQColor & );
- TQPixmap *pixmap() const { return data->pixmap; }
- void setPixmap( const TQPixmap & );
+ const TTQColor &color()const { return data->color; }
+ void setColor( const TTQColor & );
+ TTQPixmap *pixmap() const { return data->pixmap; }
+ void setPixmap( const TTQPixmap & );
- bool operator==( const TQBrush &p ) const;
- bool operator!=( const TQBrush &b ) const
+ bool operator==( const TTQBrush &p ) const;
+ bool operator!=( const TTQBrush &b ) const
{ return !(operator==(b)); }
private:
- QBrush copy() const;
+ TQBrush copy() const;
void detach();
- void init( const TQColor &, BrushStyle );
- struct QBrushData : public QShared { // brush data
+ void init( const TTQColor &, BrushStyle );
+ struct TQBrushData : public TQShared { // brush data
BrushStyle style;
- QColor color;
- QPixmap *pixmap;
+ TQColor color;
+ TQPixmap *pixmap;
} *data;
};
/*****************************************************************************
- TQBrush stream functions
+ TTQBrush stream functions
*****************************************************************************/
#ifndef QT_NO_DATASTREAM
-Q_EXPORT TQDataStream &operator<<( TQDataStream &, const TQBrush & );
-Q_EXPORT TQDataStream &operator>>( TQDataStream &, TQBrush & );
+Q_EXPORT TTQDataStream &operator<<( TTQDataStream &, const TTQBrush & );
+Q_EXPORT TTQDataStream &operator>>( TTQDataStream &, TTQBrush & );
#endif
-#endif // QBRUSH_H
+#endif // TQBRUSH_H
@@ -1,7 +1,7 @@
**
**
-** Definition of TQBrush class
+** Definition of TTQBrush class
**
** Created : 940112